@@ -10,6 +10,7 @@ import javax.swing.JFrame;
 import tim.prune.App;
 import tim.prune.config.Config;
 import tim.prune.data.Photo;
+import tim.prune.load.json.JsonFileLoader;
 import tim.prune.load.xml.GzipFileLoader;
 import tim.prune.load.xml.XmlFileLoader;
 import tim.prune.load.xml.ZipFileLoader;
@@ -142,6 +143,10 @@ public class FileLoader
 			_app.informPhotosLoaded(photoSet);
 			_app.informNoDataLoaded(); // To trigger load of next file if any
 		}
+		else if (fileExtension.equals("json"))
+		{
+			new JsonFileLoader(_app).openFile(inFile);
+		}
 		else
 		{
 			// Use text loader for everything else
